@@ -8,10 +8,8 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.6';
-#####################################################
+our $VERSION ='1.7';
 my ($class, $this, $router);
-#####################################################
 sub new(){
         $class = shift or die $!;
         $router = shift or die $!;
@@ -33,10 +31,10 @@ sub get_info(){
         $_ =~ s/\r//g;
         if (/^interface/ .. /^!/){
             if ($_ =~ /^interface/){
-               @split1 = split " ", $_;
-               $interface = $split1[1];
-               $description = '';
-               $address = '';
+                @split1 = split " ", $_;
+                $interface = $split1[1];
+                $description = '';
+                $address = '';
             }
             if ($_ =~ /^ description/){
                 $description = $_;
@@ -46,14 +44,14 @@ sub get_info(){
                 @split2 = split " ", $_;
                 $address = "$split2[2]-->$split2[3]" if $split2[3];
                 $address =~ s/\s//g;
-                $address = "No IPv4 address-->No mask" if !$split2[3];
+                $address = "No IPv4 address-->No netmask" if !$split2[3];
                 $this->{"Interface_".$interface."-->"} = "$address-->No description\n" if !$description;
                 $this->{"Interface_".$interface."-->"} = "$address-->$description\n" if $description;
             }
         }
     }
     foreach my$int (sort keys %{$this}){
-        push @interfaces, $int.$this->{$int} if $int =~ /^Interface/;
+        push @interfaces, $this->{name}."-->".$int.$this->{$int} if $int =~ /^Interface/;
     }
     return \@interfaces;
 }
@@ -61,23 +59,22 @@ sub get_info(){
 sub make_report(){
     $this = shift or die $!;
     open CSV, ">$this->{csv}" or die "Can't find csv file\n";
-    print CSV "Name;Interface;IPv4 Address;Mask;Description\n";
+    print CSV "Name;Interface;IPv4 Address;Netmask;Description\n";
     foreach my$int (sort keys %{$this}){
         my $intclean = $int;
         $intclean =~ s/^Interface_//;
         $intclean =~ s/-->/;/g;
-        $intclean.$this->{$int} =~ s/-->/;/g;
+        $this->{$int} =~ s/-->/;/g;
         print CSV $this->{name}.";".$intclean.$this->{$int} if $int =~ /^Interface/;
     }
     close CSV;
 }
-1;
+return 1;
 __END__
 
-
 =head1 NAME
 
-ios get interfaces - Get interfaces from cisco ios conf.
+ios get interfaces - Get interfaces info from cisco ios configuration file.
 
 =head1 SYNOPSIS
 
@@ -100,7 +97,7 @@ $router->make_report();
 =head1 DESCRIPTION
 
 
-Get interfaces from cisco ios conf
+Get interfaces info from cisco ios configuration file
 
 
 =head2 EXPORT
